@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub info {
     return (
@@ -19,7 +19,7 @@ sub info {
         hometown       => '広島県',
         emoticon       => ['ﾉﾘ*´ｰ´ﾘ', 'ﾉﾉs‘ _‘）'],
         class          => 9,
-        graduate_date  => undef,
+        graduate_date  => $_[0]->_datetime_from_date('2015-12-31'),
     );
 }
 
